Parallax’ Tools for the Propeller Microcontroller
=================================================

[Parallax][] provides a bunch of tools, i.e.:

 *  PropGCC, the port of GCC (the GNU Compiler Collection) to the Parallax Propeller
 *  OpenSpin, Spin/PASM compiler for the Parallax Propeller
 *  PropLoader, a loader for the Parallax Propeller
 *  SimpleIDE, a simple desktop environment (not essential, we recommend
    to use your favorite text editor)
 *  "Simple Libraries", the Parallax Learn Simple Libraries subfolder workspace


Zerocat’s Recommended Installation
----------------------------------

This recommended installation of the buildchain tools is a two step process:


### 1. Download “Simple Libraries” Folder

Parallax’ recent “Simple Libraries” shall be used, please download them like...

`$ wget https://github.com/parallaxinc/Simple-Libraries/archive/master.zip`

...and unpack the archive in `/opt/parallax/`.
A `Simple-Libraries-master` subfolder will be created.

@note
We use a snapshot as of commit c4f9a3e273002ec5e6f8b1d1ab95c14cb1823e82.

@note
This folder is available to the chipflasher’s buildchain.
See `firmware/src/buildchain.cfg` for current settings.


### 2. Installation via GNU Guix

(If not already available on your system, please install the
[GNU Guix Package Manager][]. The GNU Guix project recommends
installation using the latest release binary, which can be downloaded
here: <http://www.gnu.org/software/guix/download/>. The instructions are
linked there too.)

@note
The installation of Parallax’ tools for the Propeller microcontroller
via GNU Guix is strongly recommended by Zerocat, for project’s
buildchains are pre-configured to use GNU Guix’ installation paths.
See `firmware/src/buildchain.cfg` and `firmware/src/Startfile.cfg` for
current settings.

GNU Guix provides a very comfortable way to...

- install the complete Propeller development suite from source

  `$ guix package --no-substitutes --install propeller-development-suite`

- use precompiled binaries, which is faster, like so:

  `$ guix package --fallback --install propeller-development-suite`

  If GNU Guix reports unset environment variables, you may set them automatically:

  `$ guix environment --ad-hoc propeller-development-suite`


### 3. GNU Guix Version Reference

As a reference, see our output of `guix --version`:

    $ guix --version
    guix (GNU Guix) fddf1dc3aba3176b6efc9e0be0918245665a6ebf
    Copyright (C) 2018 the Guix authors
    License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>
    This is free software: you are free to change and redistribute it.
    There is NO WARRANTY, to the extent permitted by law.


Alternatives & Resources
------------------------

### “SimpleIDE 1.0 RC1” Binary Package

With this binary package, all tools are bundled together.
The latest packaged release for GNU/Linux is `1.0 RC1` from 11-24-2014.

@note
Until more recent source repositories of these tools will work, Parallax
suggests to install this old binary package “SimpleIDE 1.0 RC1” as a fallback.


#### Download

Please visit the [SimpleIDE Download Site][] which provides binary
packages for both, 32 and 64 bit architectures. For your convenience,
we provide shortcuts here:

~~~
$ wget http://downloads.parallax.com/plx/software/side/101rc1/simple-ide_1-0-1-rc1_amd64.deb
$ wget http://downloads.parallax.com/plx/software/side/101rc1/simple-ide_1-0-1-rc1_i386.deb
~~~

This site should guide you towards [linux installation instructions][] as well.


#### Former Linux Installation Instructions

For your convenience, we provide our backup of former installation
instructions, that are known to work.

* Linux Directions, as adapted from Parallax

  Supports Debian, Mint, and Ubuntu Linux (Intel 32/64­bit)

  Please note the dollar sign ($) represents the command prompt in the steps below.
  If you see `$ command`, it means enter `command` in your command terminal window.
  Installation requires using the Linux Terminal.  The steps below assume you’re
  logged in with a user account (non-­root access) but do know the root password.
  NOTE: In Trisquel7, use `$ sudo -s` to become root.

  To Install:

  1.  Download appropriate .deb package (i386 for 32­bit systems or i686/amd64 for 64­bit systems)
  2.  Open a terminal and  CD  to the download folder
  3.  Enter `$ sudo dpkg ­-i simple-ide_1-0-1-rc1_amd64.deb`
      (adjust the filename to match what was downloaded)
      a. You may get errors due to dependencies, the next step will take care of that.
  4.  Enter  `$ sudo apt-­get install -­f`
  5.  Answer yes `Y` as required to install dependencies
  6.  If your user account is not part of the `dialout` group, you must
      add it or `propeller-load` won’t be able to download to the Propeller
      a.  Enter `$ sudo adduser ${USER} dialout`
      b.  Log out from the system completely, then log back in for permissions to take effect
  7.  To remove the package, use `$ sudo apt-­get remove simpleide`


#### Related Source Repositories

Original repositories of the first bundle release (SimpleIDE 1.0 RC1):

- SimpleIDE, the Desktop Environment

  <https://github.com/parallaxinc/SimpleIDE>

- Simple Libraries, Contents of the SimpleIDE workspace folder and its
  Parallax Learn Simple Libraries subfolder

  <https://github.com/parallaxinc/Simple-Libraries>

- PropGCC, the port of GCC (the GNU Compiler Collection) to the Parallax
  Propeller

  <https://github.com/parallaxinc/propgcc/>

  As stated by Jeff Martin from Parallax, the content at the tip of
  the *release_1_0* branch should match the proper sources:

  <https://github.com/parallaxinc/propgcc/tree/release_1_0>

- OpenSpin, open source compiler for the Spin/PASM language of the Parallax
  Propeller

  <https://github.com/parallaxinc/OpenSpin>

- PropLoader, a loader for the Parallax Propeller

  <https://github.com/parallaxinc/PropLoader/>


### New Source Repositories

These are newer repositories from David Betz.

- propeller-gcc compiler

  <https://github.com/dbetz/propeller-gcc>

  Switching over to these sources was not yet successful.

- propeller-load

  <https://github.com/dbetz/propeller-load>

@note
Until these repositories will work, Parallax suggests to install the
old binary package “SimpleIDE 1.0 RC1” as a fallback.



[Parallax]:                             https://www.parallax.com/
[SimpleIDE Download Site]:              https://www.parallax.com/downloads/simpleide-propeller-c-software-linux
[linux installation instructions]:      http://www.learn.parallax.com/propeller-c-set-simpleide
[GNU Guix Package Manager]:             https://www.gnu.org/software/guix/


-----------------------------------------------------------------------

  @copyright
  Copyright (C) 2017, 2018 Kai Mertens <kmx@posteo.net> @n
  Permission is granted to copy, distribute and/or modify this document
  under the terms of the GNU Free Documentation License, Version 1.3
  or any later version published by the Free Software Foundation;
  with no Invariant Sections, no Front-Cover Texts, and no Back-Cover
  Texts. A copy of the license is included in the section entitled:
  [GNU Free Documentation License](COPYING-DOCUMENTATION.md)

