##>!
##>! Zerocat Chipflasher --- Flash free firmware to BIOS chips,
##>!                         kick the Manageability Engine.
##>!
##>! Copyright (C) 2017, 2018 Kai Mertens <kmx@posteo.net>
##>!
##>! The Zerocat Chipflasher is free software: you can redistribute it
##>! and/or modify it under the terms of the GNU General Public License
##>! as published by the Free Software Foundation, either version 3 of
##>! the License, or (at your option) any later version.
##>!
##>! The Zerocat Chipflasher is distributed in the hope that it will be
##>! useful, but WITHOUT ANY WARRANTY; without even the implied warranty
##>! of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##>! GNU General Public License for more details.
##>!
##>! You should have received a copy of the GNU General Public License
##>! along with this program.  If not, see <http://www.gnu.org/licenses/>.
##>!
##>! This file is part of the Zerocat Chipflasher.
##>!
##>!
##>! @file Startfile.mk
##>!
##>! @brief Operate the chipflasher.
##>!
##>! Usage:
##>!  `$ make -f Startfile.mk <target>`
##>!

##>! @cond
#######################################################################
# Variable settings for sub-shells. FIXME refine this:
# Have to set shell explicitly for PATH setting to take effect (why?)
SHELL := /bin/bash


#######################################################################
# Options
PATH_PARALLAX = /opt/parallax/
PATH_GNUGUIX = /var/guix/profiles/per-user/$(USER)/guix-profile/
PATH_HOST_SRC = ../../host/src/
PROPLOAD_PARALLAX = $(PATH_PARALLAX)bin/propeller-load
PROPLOAD_GNUGUIX = $(PATH_GNUGUIX)bin/propeller-load


#######################################################################
# Settings
#  possibly to be overridden by those in Startfile.cfg
PROPLOAD = $(PROPLOAD_PARALLAX)
-include Startfile.cfg


#######################################################################
# options for propeller-load and connect
TTY_PORT = ./tty_port_pointer

# TTY_BAUDRATE: If you update this to other values like B38400 or B57600,
# please don't forget to update 'baudrate' in board.cfg accordingly!
TTY_BAUDRATE = B115200
#~ TTY_BAUDRATE = B38400

CHIP2FILE = chip2file.txt
FILE2CHIP = file2chip.txt


#######################################################################
# Explicit dependencies
.PHONY: terminal loadram loadrom startram startrom start

# load kick into ram, run and start a propeller-terminal
terminal:
	$(PROPLOAD) -p $(TTY_PORT) -b board:terminal kick.elf -r -t -q;

# load kick into ram and run
loadram:
	$(PROPLOAD) -p $(TTY_PORT) -b board:rstdisable kick.elf -r; \
	sleep 1.5s;

# load kick into eeprom, don't run
loadrom:
	$(PROPLOAD) -p $(TTY_PORT) -b board kick.elf -e;

# load kick into RAM and start connect
startram: loadram start

# load kick into eeprom and start connect
startrom: loadrom start

# start connect
start:
	$(PATH_HOST_SRC)./connect $(CHIP2FILE) $(FILE2CHIP) $(TTY_PORT) $(TTY_BAUDRATE);


#######################################################################
# FIXME Those steps missing:
#  propeller-load -s cmm/libfdserial.elf
#  propeller-elf-objdump -h cmm/libfdserial.elf
##>! @endcond
