/******************************************************************//**
 * Zerocat Chipflasher --- Flash free firmware to BIOS chips,
 *                         kick the Manageability Engine.
 *
 * Copyright (C) 2015, 2016, 2017, 2018 Kai Mertens <kmx@posteo.net>
 *
 * The Zerocat Chipflasher is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * The Zerocat Chipflasher is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This file is part of the Zerocat Chipflasher.
 *
 *
 * @file
 *
 * @brief
 * Known SPI commands, one byte.
 *
 */

#ifndef __SPI_COMMAND_SET_H__
#define __SPI_COMMAND_SET_H__

/**
 * @defgroup CommandSetSpi SPI Command Set
 *
 * @brief
 * Selected SPI commands that are known to the chipflasher.
 *
 */



/**
 * @ingroup CommandSetSpi
 * @{
 */
#define CMD__NOP          0x00  //!< No Operation
#define CMD__EWSR         0x50  //!< Enable Write Status Register
#define CMD__WRSR         0x01  //!< Write Status Register 1
#define CMD__WRSR2        0x31  //!< Write Status Register 2
#define CMD__WRSR3        0x11  //!< Write Status Register 3
#define CMD__WRDI         0x04  //!< Write Disable
#define CMD__RDSR         0x05  //!< Read Status Register 1
#define CMD__RDSR2        0x35  //!< Read Status Register 2
#define CMD__RDSR3        0x15  //!< Read Status Register 3
#define CMD__WREN         0x06  //!< Write Enable
#define CMD__RDID         0x9f  //!< Read JEDEC Device ID
#define CMD__READ         0x03  //!< Read (at up to 25MHz)
#define CMD__READHF       0x0b  //!< Read High Frequency (> 25MHz)
#define CMD__SE           0x20  //!< Sector Erase (4K)
#define CMD__BE32K        0x52  //!< Block Erase (32K)
#define CMD__BE64K        0xd8  //!< Block Erase (64K)
#define CMD__CE_0X60      0x60  //!< Full Chip Erase (0x60)
#define CMD__CE_0XC7      0xc7  //!< Full Chip Erase (0xc7)
#define CMD__BP           0x02  //!< Byte Program
#define CMD__PP           0x02  //!< Page Program
#define CMD__CP           0xad  //!< Continuous Program
#define CMD__DP           0xb9  //!< Deep Powerdown
#define CMD__RDP          0xab  //!< Release from Deep Powerdown
#define CMD__RES          0xab  //!< Read Electronic ID
#define CMD__REMS         0x90  //!< Read electronic manufacturer & device ID
#define CMD__ESRY         0x70  //!< enable SO to output RDY/_BSY during CP-Mode
#define CMD__DSRY         0x80  //!< disable SO to output RDY/_BSY during CP-Mode
#define CMD__PS           0x36  //!< Protect Sector
#define CMD__US           0x39  //!< Unprotect Sector
#define CMD__RSPR         0x3c  //!< Read Sector Protect Registers
/** @} */

#endif
/* __SPI_COMMAND_SET_H__ */
