/******************************************************************//**
 * Zerocat Chipflasher --- Flash free firmware to BIOS chips,
 *                         kick the Manageability Engine.
 *
 * Copyright (C) 2015, 2016, 2017, 2018 Kai Mertens <kmx@posteo.net>
 *
 * The Zerocat Chipflasher is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * The Zerocat Chipflasher is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This file is part of the Zerocat Chipflasher.
 *
 *
 * @file
 *
 * @brief
 * Common Bit Names of important SPI Flash Registers.
 *
 */

#ifndef __SPI_FLASH_BITS_H__
#define __SPI_FLASH_BITS_H__

//Status Register Bits, most common, but names may vary.
#define SRWD              0x80  //!< Status Register Write Disable
#define CPM               0x40  //!< Continously Program Mode
#define BP3               0x20  //!< Block Protect 3
#define BP2               0x10  //!< Block Protect 2
#define BP1               0x08  //!< Block Protect 1
#define BP0               0x04  //!< Block Protect 0
#define WEL               0x02  //!< Write Enable Latch
#define WIP               0x01  //!< Write In Progress

//Security Register on some Macronix Types
#define SOTPI             0x01  //!< Secured OTP Indicator Bit. Indicates wether SOTP had been locked by factory (1) or customer (0).
#define LDSO              0x02  //!< Lock-down Secured OTP (can't be reset!).

#endif
/* __SPI_FLASH_BITS_H__ */
