/******************************************************************//**
 * Zerocat Chipflasher --- Flash free firmware to BIOS chips,
 *                         kick the Manageability Engine.
 *
 * Copyright (C) 2015, 2016, 2017, 2018 Kai Mertens <kmx@posteo.net>
 *
 * The Zerocat Chipflasher is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * The Zerocat Chipflasher is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This file is part of the Zerocat Chipflasher.
 *
 *
 * @file
 *
 */

#ifndef __FILESPEC_C__
#define __FILESPEC_C__

struct tag_filespec filespec[2] = {
  {
    //to be calculated:
    PAYLOAD_BASE,
    //fixed:
    MOTBIN,
    MODE_MOTBIN,
    "Motorola-S"
  },
  {
    //to be calculated:
    PAYLOAD_BASE,
    //fixed:
    HEXDUMP,
    MODE_HEXDUMP,
    "Hex-Dump"
  }
};


inline int payload(
  enum tag_format format,
  int chipsize
  )
{
  if(format != HEXDUMP) {
    if(chipsize > (1 << 16))  //64K
      return PAYLOAD_BASE << 2;
    if(chipsize > (1 << 8))   //256
      return PAYLOAD_BASE << 1;
  }
  return PAYLOAD_BASE;
}



void filespec_ini(
  int chipsize
  )
{
  struct tag_filespec *p;
  int n = ARRAY_FILESPEC;

  while(n--) {
    p = &filespec[n];
    p->payload_default = payload(p->format, chipsize);
  }
}

#endif
/* __FILESPEC_C__ */
