/******************************************************************//**
 * Zerocat Chipflasher --- Flash free firmware to BIOS chips,
 *                         kick the Manageability Engine.
 *
 * Copyright (C) 2015, 2016, 2017, 2018 Kai Mertens <kmx@posteo.net>
 *
 * The Zerocat Chipflasher is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * The Zerocat Chipflasher is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This file is part of the Zerocat Chipflasher.
 *
 *
 * @file
 *
 */

#ifndef __FILESPEC_H__
#define __FILESPEC_H__

#define SIZE_LINEBUF        (1 << 8)
#define HEADER              "Zerocat Chipflasher (http://www.zerocat.org) | %s"
#define FRAME_HEADER        15  //arbitrary for all formats
#define SIZE_HEADER         (SIZE_LINEBUF - FRAME_HEADER)
#define ARRAY_FILESPEC      2
#define PAYLOAD_BASE        (1 << 4)  //if different, srec_cat won't understand our hexdump file
#define FRAME_MOTBIN        17
#define SHIFT_MOTBIN        0
#define FRAME_HEXDUMP       15
#define SHIFT_HEXDUMP       2

//modes for mode_0xff, used by chip_read()
#define MODE_INLINE         0x1F
#define MODE_SPLIT          0x20
#define MODE_STRIP          0x40
#define MODE_SCREEN_OUTPUT  0x80
#define MODE_HEXDUMP        (MODE_INLINE & 0x00)
#define MODE_MOTBIN         ((MODE_INLINE & 0x10) | MODE_SPLIT | MODE_STRIP)

//HEXDUMP
#define HEXDUMP_LINELEN     (10 + PAYLOAD_BASE * 4 + 2 + 2)

enum tag_format {
  MOTBIN = 0,
  HEXDUMP
};

struct tag_filespec {
  unsigned char payload_default;      //!< Pure data bytes per line.
  enum tag_format format;
  unsigned char mode_0xff;
  char *format_name;
};

void filespec_ini(
  int chipsize
  );

inline int payload(
  enum tag_format format,
  int chipsize
  );

#endif
/* __FILESPEC_H__ */

