/******************************************************************//**
 * Zerocat Chipflasher --- Flash free firmware to BIOS chips,
 *                         kick the Manageability Engine.
 *
 * Copyright (C) 2015, 2016, 2017, 2018 Kai Mertens <kmx@posteo.net>
 *
 * The Zerocat Chipflasher is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * The Zerocat Chipflasher is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This file is part of the Zerocat Chipflasher.
 *
 *
 * @file
 *
 */

/******************************************************************//**
 * @ingroup Motorola
 *
 * @brief
 * Helps to detect wether the byte in question is part of the line’s
 * S-record frame or if it is part of the (binary) payload.
 *
 * @return
 * Returns 1 to indicate a payload, otherwise zero.
 *
 */
int line_info(
  char file_format,
  int *linepos,
  char c,
  //HEXDUMP:
  struct tag_hexdumpline *hexdumpline,
  //MOT, MOTBIN:
  struct tag_motline *motline,
  int hexmode
  )
{
  int r = 0;

  /*
   * NOTE
   * *linepos == -1:  This function has no effect, return value is zero.
   * *linepos == 0:   Is not used.
   * *linepos == 1:   Points to first byte of line.
   */

  if(*linepos > -1) {     //is line scanner active?
    if(*linepos == 0) {   //initialize
      //clear structs for line_info()
      if(motline != NULL) {
        motline->linelen = 0;
        motline->addrlen = 0;
        motline->pos_addrlsb = 0;
        motline->payload_orig = 0;
        motline->payload = 0;
        motline->length = 0;
        motline->checksum = 0;
        motline->chksum_rx = 0;
      }
      if(hexdumpline != NULL) {
        hexdumpline->is_charset_print = OFF;
        hexdumpline->is_comment_line = OFF;
        hexdumpline->is_first = '-';
      }
    }
    *linepos += 1;  //let's start with value 1, which is easier to understand
    switch(file_format) {
      case MOTBIN:
        switch(*linepos) {
          case 0:   //not used
            break;

          case 1:   //'S' character
            break;

          case 2:
            motline->addrlen = MOT_addrlen(c);
            motline->pos_addrlsb = 4 + motline->addrlen * 2;
            break;

          case 3:
            motline->linelen = hexdigit2bin(c) << 4;
            break;

          case 4:
            motline->linelen |= hexdigit2bin(c);
            motline->checksum = motline->linelen;   //start summing checksum
            //payload_orig: don't count address bytes and checksum
            motline->payload_orig = (motline->linelen - motline->addrlen - 1) << (hexmode ? 1 : 0);
            motline->length = motline->linelen + motline->addrlen + 8;
            break;

          default:
            if(*linepos <= motline->pos_addrlsb)
              motline->checksum += (*linepos % 2) ? hexdigit2bin(c) << 4 : hexdigit2bin(c);
            if(*linepos == motline->pos_addrlsb)
              motline->payload = motline->payload_orig;
            else if(motline->payload) {
              motline->checksum += c;
              motline->payload--;
              r = 1;
            }
            if(*linepos == motline->pos_addrlsb + motline->payload_orig + 1)
              motline->chksum_rx = hexdigit2bin(c) << 4;
            if(*linepos == motline->pos_addrlsb + motline->payload_orig + 2) {
              motline->chksum_rx |= hexdigit2bin(c);
              motline->checksum = ~motline->checksum;
            }
            break;
        }
        break;

      case HEXDUMP:
        if(*linepos == 1)
          hexdumpline->is_first = c;
        if(c == '#') {
          hexdumpline->is_charset_print = ON;
          if(*linepos == 1)
            hexdumpline->is_comment_line = ON;
        }
        break;
    }
  }
  return r;
}
