/******************************************************************//**
 * Zerocat Chipflasher --- Flash free firmware to BIOS chips,
 *                         kick the Manageability Engine.
 *
 * Copyright (C) 2015, 2016, 2017, 2018 Kai Mertens <kmx@posteo.net>
 *
 * The Zerocat Chipflasher is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * The Zerocat Chipflasher is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This file is part of the Zerocat Chipflasher.
 *
 *
 * @file
 *
 */

#ifndef __SERIAL_CODES_H__
#define __SERIAL_CODES_H__

/**
 * @defgroup SerialCodes Serial Control Codes
 *
 * @brief
 * One char codes that help to build a simple protocol for the
 * kick-connect communication.
 *
 */



/**
 * @ingroup SerialCodes
 * @{
 */
// serial control codes
#define NUL             0x00    //!< "\0"
#define SOH             0x01    //!< Ascii 'start of header'
#define STX             0x02    //!< Ascii 'start of text'.
#define ETX             0x03    //!< Ascii 'end of text'.
#define EOT             0x04    //!< Ascii 'end of transmission'
#define ENQ             0x05    //!< Ascii 'enquiry'
#define ACK             0x06    //!< Ascii 'acknoledge'
#define NEW_LINE        0x0a    //!< Ascii LF "\n" 'line feed'
#define CARR_RET        0x0d    //!< Ascii CR "\r" 'carriage return'
#define NAK             0x15    //!< Ascii 'neg. acknoledge'
#define SYN             0x16    //!< Ascii 'synchronous idle'
#define ETB             0x17    //!< Ascii 'end of block transmission'
#define CAN             0x18    //!< Ascii 'cancel'
#define EM              0x19    //!< Ascii 'end of medium'
#define SUB             0x1a    //!< Ascii 'substitute'
#define ESC             0x1b    //!< Ascii 'escape'
#define FS              0x1c    //!< Ascii 'file seperator'
#define GS              0x1d    //!< Ascii 'group seperator'
#define RS              0x1e    //!< Ascii 'record seperator'
#define US              0x1f    //!< Ascii 'unit seperator'
//line ending characters
#define CLIM_CR         CARR_RET
#define CLIM_NL         NEW_LINE
#define CLIM_HEXDUMP    CLIM_CR
//parallax terminal exit sequence
#define EXIT_CHAR_A     0xff    //!< First char of Parallax' exit sequence.
#define EXIT_CHAR_B     0x00    //!< Second char of Parallax' exit sequence.
//chipflasher file actions
#define CHIP_TO_FILE            0x20    //!< Send data to terminal and save on disk.
#define CHIP_TO_FILE_NOSCREEN   0x21    //!< Send data to terminal and save on disk, without feedback on screen.
#define FILE_TO_CHIP            0x22    //!< Send data to propeller and write to chip.
#define FILE_TO_CHIP_NOSCREEN   0x23    //!< Send data to propeller and write to chip, without output on screen.
/** @} */



/**
 * @ingroup SerialCodes
 *
 * @brief
 * Error codes.
 *
 * @todo
 * Add member comments.
 *
 */
#define ERRC__SUCCESS                   0     //connect & kick
#define ERRC__JOB_CANCELLATION          1     //connect & kick
#define ERRC__NO_MOT                    2     //kick
#define ERRC__NO_HEX_DIGIT              3     //kick
#define ERRC__LINE_ENDING_ERROR         4     //kick
#define ERRC__LINE_COUNT_MISMATCH       5     //kick
#define ERRC__LINE_TOO_LONG             6     //kick
#define ERRC__BUFFER_OVERRUN            7     //kick
#define ERRC__HEXDUMP_PARSING_ERROR     8     //kick
#define ERRC__NO_SUCH_FILE              9     //connect
#define ERRC__CHECKSUM_MISMATCH         10    //connect & kick
#define ERRC__LINE_LENGTH_MISMATCH      11    //connect
#define ERRC__OUT_OF_CHARSET            12    //connect
#define ERRC__LINE_TIMEOUT              13    //connect
#define ERRC__PORT_OPEN_FAILURE         14    //connect

#endif
/* __SERIAL_CODES_H__ */

