/******************************************************************//**
 * Zerocat Chipflasher --- Flash free firmware to BIOS chips,
 *                         kick the Manageability Engine.
 *
 * Copyright (C) 2015, 2016, 2017, 2018 Kai Mertens <kmx@posteo.net>
 *
 * The Zerocat Chipflasher is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * The Zerocat Chipflasher is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This file is part of the Zerocat Chipflasher.
 *
 *
 * @file
 *
 * @brief
 * Entities that help to configure allowed key input.
 * With these keys associated are predefined strings that are used as
 * menu options and input feedback at the same time.
 *
 */

#ifndef __KEY_ENABLE_BITS_H__
#define __KEY_ENABLE_BITS_H__

//Key Enable IDs
#define KEYID_q             0
#define KEYID_d             1
#define KEYID_t             2
#define KEYID_p             3

#define KEYID_s             4
#define KEYID_S             5
#define KEYID_k             6
#define KEYID_K             7

#define KEYID_b             8
#define KEYID_B             9
#define KEYID_c             10
#define KEYID_C             11

#define KEYID_I             12
#define KEYID_f             13
#define KEYID_G             14
#define KEYID_r             15

#define KEYID_W             16
#define KEYID_m             17
#define KEYID_X             18

#define ID_NONE             31    //special ID for "no key"

// Key Enable Register Bits
#define KEYBIT_q            (1 << KEYID_q)
#define KEYBIT_d            (1 << KEYID_d)
#define KEYBIT_t            (1 << KEYID_t)
#define KEYBIT_p            (1 << KEYID_p)

#define KEYBIT_s            (1 << KEYID_s)
#define KEYBIT_S            (1 << KEYID_S)
#define KEYBIT_k            (1 << KEYID_k)
#define KEYBIT_K            (1 << KEYID_K)

#define KEYBIT_b            (1 << KEYID_b)
#define KEYBIT_B            (1 << KEYID_B)
#define KEYBIT_c            (1 << KEYID_c)
#define KEYBIT_C            (1 << KEYID_C)

#define KEYBIT_I            (1 << KEYID_I)
#define KEYBIT_f            (1 << KEYID_f)
#define KEYBIT_G            (1 << KEYID_G)
#define KEYBIT_r            (1 << KEYID_r)

#define KEYBIT_W            (1 << KEYID_W)
#define KEYBIT_m            (1 << KEYID_m)

#define KEYBIT_X            (1 << KEYID_X)

//default keyreg value
#define KEYREG_DEFAULT      KEYBIT_q | KEYBIT_d | KEYBIT_f | KEYBIT_t;

unsigned int keyreg = 0;

/*
 * NOTE Keep the initial string format layout (i.e. "[x] some-text-here"),
 * because string position 1 and 3 (i.e. 'x' and ' ') are scanned for
 * key input comparison. Do not use <space> as a key symbol on position
 * three.
 */
char *keymsg[] = {
  "[q]   (SPI off)/cancel/quit",//0
  "[d]   detect chip",          //1
  "[t]   toggle format",        //2
  "[p]   read page ",           //3

  "[s]   4k block read",        //4
  "[S]   4k block erase",       //5
  "[k]   32k block read",       //6
  "[K]   32k block erase",      //7

  "[b]   64k block read",       //8
  "[B]   64k block erase",      //9
  "[c]   read chip ",           //10
  "[C]   erase chip",           //11

  "[I]   flash file",           //12
  "[f]   force chip",           //13
  "[G]   global sector protect",//14
  "[r]   show status register", //15

  "[W]   set status register",  //16
  "[m]   read random",          //17
  "[X]   global sector unprotect" //18
};

#endif
/* __KEY_ENABLE_BITS_H__ */
