/******************************************************************//**
 * Zerocat Chipflasher --- Flash free firmware to BIOS chips,
 *                         kick the Manageability Engine.
 *
 * Copyright (C) 2015, 2016, 2017, 2018 Kai Mertens <kmx@posteo.net>
 *
 * The Zerocat Chipflasher is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * The Zerocat Chipflasher is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This file is part of the Zerocat Chipflasher.
 *
 *
 * @file
 *
 * @brief
 * Propeller Pin Usage and predefined Bit Values.
 *
 */

#ifndef __PROPPINS_H__
#define __PROPPINS_H__

/**
 * @defgroup PropPins Propeller Pin Usage
 *
 * @brief
 * These pins are used on the chipflasher board. Pins may be
 * accessed via bitmasks over DIRA, OUTA, INA directly.
 *
 * @note
 * Pins 0..8 are fast addressable.
 *
 */



/**
 * @ingroup PropPins
 * @{
 */
//fast addressable pins 0..8
#define PIN_CEn           0   //!< Chip Enable Pin, active low.
#define PIN_CEn_1         1   //!< Auxiliary Chip Enable
#define PIN_MOSI          2   //!< Propeller's Shift Out Pin.
#define PIN_WPn           3   //!< Write Protect Pin, active low.
#define PIN_SCLK3         4
#define PIN_SCLK2         5
#define PIN_SCLK1         6
#define PIN_SCLK0         7
#define PIN_MISO          8   //!< Propeller's Shift In Pin.
//slow addressable pins
#define PIN_PLUGTESTn     9   //!< This pin is used detect an adapter plug
#define PIN_PNP           10  //!< control spi power through pnp MOSFET, high=off
#define PIN_HOLDn         12  //!< Hold Pin, active low.
#define LED_YELLOW        13  //!< Attached board or chip is powered.
#define LED_ORANGE        14  //!< SPI pins are actively driven, do not remove board's power.
#define LED_GREEN         15  //!< SPI pins are tristate, you can safely attach/detach board.
#define RST_DISABLE       16
#define PIN_RX            31
#define PIN_TX            30
//bit values
#define BIT_LED_YELLOW    (1 << LED_YELLOW)
#define BIT_LED_ORANGE    (1 << LED_ORANGE)
#define BIT_LED_GREEN     (1 << LED_GREEN)
#define BIT_PNP           (1 << PIN_PNP)
#define BIT_SCLK3         (1 << PIN_SCLK3)
#define BIT_SCLK2         (1 << PIN_SCLK2)
#define BIT_SCLK1         (1 << PIN_SCLK1)
#define BIT_SCLK0         (1 << PIN_SCLK0)
#define BIT_WPn           (1 << PIN_WPn)
#define BIT_MISO          (1 << PIN_MISO)
#define BIT_CEn           (1 << PIN_CEn)
#define BIT_CEn_1         (1 << PIN_CEn_1)
#define BIT_HOLDn         (1 << PIN_HOLDn)
#define BIT_MOSI          (1 << PIN_MOSI)
#define BIT_PLUGTESTn     (1 << PIN_PLUGTESTn)

#define BIT_PNP_DEVICE    BIT_PNP
#define CEn_AVAIL         (BIT_CEn | BIT_CEn_1)
#define SCLK_AVAIL        (BIT_SCLK0 | BIT_SCLK1 | BIT_SCLK2 | BIT_SCLK3)
#define SPI_BUS           (CEn_AVAIL | BIT_MOSI | BIT_WPn | BIT_HOLDn | SCLK_AVAIL | BIT_MISO)

/**
 * @note
 * We can drive the SCK line with different current setups, 4 pins are
 * available.
 * - The T500-8MB-Winbond testboard requires only one pin.
 * - The X200-8MB-Winbond testboard requires three pins.
 * - The X60s-2MB-SST     testboard requires only one pin.
 *
 */
#define SCLK_ACTIVE       (BIT_SCLK0 | BIT_SCLK1 | BIT_SCLK2 | BIT_SCLK3)
/** @} */

#endif
/* __PROPPINS_H__ */
