#!/bin/bash

# Copy gEDA-gschem symbols from the working directory into gEDA's symbol directory 'local',
# the symbols will then be visible to gEDA and gschem.

# setup source and dest
SRC_FILES="./*.sym"
DEST="/usr/share/gEDA/sym/local/"

# do we have root priviledges?
function test_root () {
  if [[ $EUID -ne 0 ]]; then
     echo "This script must be run as root.";
     exit 1;
  fi
}

# does the /usr/share/gEDA/sym/local/ directory exist?
function test_dirlocal () {
  if [[ -d $DEST ]]; then
    echo "Ok, gEDA's symbol directory 'local' exists."
  else
    echo "$0: cannot find /usr/share/gEDA/sym/local/"
    exit 1;
  fi
}

# save user
function save_user () {
  USER=$(whoami);
  USER_DEST=$(ls -lo $DEST/.. | grep local | cut -d ' ' -f 3);
# echo $USER;
# echo $USER_DEST;
}

# query permissions
function query_perm () {
  #PERMSTAT=$(ls -al $DEST/.. | grep local | cut -d ' ' -f 1);
  PERMSTAT=$(ls -al $DEST/.. | grep local | cut -b 2-4 | tr -d "-");
# echo "Original permissions: $PERMSTAT";
}

# restore permissions
function restore_perm () {
  chmod u+$PERMSTAT $DEST;
# echo "Permissions restored to: $PERMSTAT";
}
  
# done.
function quit () {
  echo "Done."
  echo "All symbols are now available to gEDA/gschem."
  echo "Backups have eventually been created."
  exit 0;
}

# setup temporary write permissions and copy symbols
function copy_symbols () {
  if [[ $USER -eq $USER_DEST ]];
  then
    query_perm;
    chmod u+w "$DEST/..";
    cp --backup=numbered ./*.sym "$DEST";
    restore_perm;
  else
    echo "$DEST is not owned by $USER.";
    exit 1;
  fi
}

#script starts here...
test_root;
test_dirlocal;
save_user;
copy_symbols;
quit;
