/******************************************************************//**
 * Zerocat Chipflasher --- Flash free firmware to BIOS chips,
 *                         kick the Manageability Engine.
 *
 * Copyright (C) 2015, 2016, 2017, 2018 Kai Mertens <kmx@posteo.net>
 *
 * The Zerocat Chipflasher is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * The Zerocat Chipflasher is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This file is part of the Zerocat Chipflasher.
 *
 *
 * @file
 *
 */

#ifndef __CONNECT_H__
#define __CONNECT_H__

//start diagnostic compiler switches
//~ #define ERROR_MSG_READOUT
//end diagnostic compiler switches

#include "../../firmware/src/libcommon/serial-codes.h"    //include serial control codes
#include "ANSI-color-escape-sequences.h"
#include <ctype.h>

#define SIZE_PORT           6
#define PORT_DEFAULT        0
#define SIZE_RATE           8
#define RATE_DEFAULT        5
#define RESET_DURATION      300000

#define HEADER_LICENSE      MSG_LIC \
                            "Zerocat Chipflasher Copyright (C) 2015–2018 Kai Mertens\n\n" \
                            "This program comes with ABSOLUTELY NO WARRANTY. This is free software,\n" \
                            "and you are welcome to redistribute it under certain conditions.\n" \
                            "See git://zerocat.org/zerocat/projects/chipflasher/ for details.\n"
#define HEADER_CONNECT      " Zerocat Chipflasher: connect " VERSION " "
#define FILE_TO_SEND        "file2chip.txt"
#define FILE_TO_CATCH       "chip2file.txt"

#define MARK                0x00    //!< Digital 1, -5V on serial line.
#define SPACE               0x01    //!< Digital 0, +5V on serial line.

#undef  MAX
#define MAX(x,y)            ((x) > (y) ? (x) : (y))

#define EXITFAIL(msg)       do { \
                              fprintf(stderr, MSG_ERROR); \
                              perror(msg); \
                              fprintf(stderr, "\r"MSG_RESET); \
                              if(fdtty > -1) \
                                close(fdtty); \
                              if(fdrd > -1) \
                                close(fdrd); \
                              if(fdwr > -1) \
                                close(fdwr); \
                              exit(EXIT_FAILURE); \
                            } while(0)

#define WRITE_BUF_STDOUT(c)       do { \
                                    if(pwr_stdout == SIZE_BUF_STDOUT) { \
                                      EXITFAIL("polling(): stdout buffer overflow"); \
                                    } \
                                    else { \
                                      *(buf_stdout + pwr_stdout++) = c; \
                                    } \
                                  } while(0)

#define WRITESTR_BUF_STDOUT(s)    do { \
                                    int i = 0; \
                                    int n = sizeof(s); \
                                    do { \
                                      if(pwr_stdout == SIZE_BUF_STDOUT) \
                                        EXITFAIL("polling(): stdout buffer overflow"); \
                                      *(buf_stdout + pwr_stdout++) = *(s + i++); \
                                    } while(--n); \
                                  } while(0)

#define WRITE_BUF_FILE(c)         do { \
                                    if(pwr_file == SIZE_BUF_FILE) { \
                                      EXITFAIL("polling(): file buffer overflow"); \
                                    } \
                                    else \
                                      *(buf_file + pwr_file++) = c; \
                                  } while(0)

#define TIMEOUT_SEC         0           //pselect timeout setting, full seconds
#define TIMEOUT_NSEC        200000000   //pselect timout setting, nanoseconds
#define LINE_RETRY          5           //How many trials before aborting?

#ifdef ERROR_MSG_READOUT
  #define WAIT_AFTER_ERROR   1000000      //avoid instant scrolling, wait some time (µsec)
#endif

#define SIZE_BUF_RDTTY      512
#define SIZE_BUF_STDOUT     512
#define SIZE_BUF_FILE       512
#define FLUSH_NO_INPUT      0
#define FLUSH_WITH_INPUT    1
#define MSG_LIC                         FG_WHITE "\r\n"
#define MSG_START                       FG_GREEN "\r\n"
#define MSG_WARN                        FG_YELLOW "\r\n"
#define MSG_ERROR                       FG_RED "\r\n"
#define MSG_STOP                        FG_DARKGRAY "\r\n"
#define MSG_RESET                       RESET_ALL "\r\n"
#define WRITE_BUF_STDOUT__MSG_START     WRITESTR_BUF_STDOUT(FG_GREEN)
#define WRITE_BUF_STDOUT__MSG_STOP      WRITESTR_BUF_STDOUT(FG_DARKGRAY)



enum tag_filestep {
  start_file_readout = 0,
  byte_preview,
  check_stx,
  check_CRNL,
  send_byte,
  send_clim,
  send_etx_or_can,
  wait_char,
  receive_ack,
  receive_nak,
  receive_can,
  send_eot,
  flush_buffers,
  close_tx
};

int get_DTR(
  int fdtty
  );

void set_DTR (
  int fdtty,
  int level
  );

void set_RTS (
  int fdtty,
  int level
  );

void greeting (
  const char *port,
  const char *rate
  );

void goodbye(
  void
  );

int connect (
  char * dev,
  const speed_t baudrate,
  unsigned int bps
  );

void restore_stdout (
  void
  );

char polling(
  int fdtty
  );

void put_error (
  char errcode,
  int retry_count
  );

int testflush_stdout(
  int mode,
  char c
  );

int testflush_file(
  char *pc
  );

void headline (
  void
  );

void lock_tty(
  int fdtty
);

void unlock_tty(
  int fdtty
);

#endif
/* __CONNECT_H__ */
