#!/bin/bash
#
# Zerocat Chipflasher --- Flash free firmware to BIOS chips,
#                         kick the Manageability Engine.
#
# Copyright (C) 2017, 2018 Kai Mertens <kmx@posteo.net>
#
# The Zerocat Chipflasher is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# The Zerocat Chipflasher is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# This file is part of the Zerocat Chipflasher.
#
# srec2bin.sh
#
# Convert lines of Motorola S-Record into a binary rom of a dedicated size.
#
# usage: bash srec2bin.sh in.srec out.bin size_hex
#   in.srec:    text file in Motorola S-record format
#   rom.bin:    raw binary file of a dedicated size
#   size_hex:   size of the binary in hexadecimal value, i.e. 0x800000 for 8MB
#

echo $0 "-- Convert Motorola S-Record data into binary data of a dedicated size.";

if ( ! [ "${1}" ] || ! [ "${2}" ] || ! [ "${3}" ] );
then
  echo;
  echo $0" usage:";
  echo "  bash "$0" in.srec out.bin size_hex";
  echo "  in.srec:    A text file in Motorola-S file format.";
  echo "  out.bin:    A binary ROM image.";
  echo "  size_hex:   Size of the binary in hexadecimal value, i.e. 0x800000 for 8MB.";
  echo;
  exit 0;
fi

if ( ! [ -a $1 ] );
then
  echo "Input file "$1" doesn't exist. Exiting.";
  exit 1;
fi

if [ -a $2 ];
then
  echo "Output file "$2" already exists. Exiting.";
  exit 1;
fi

srec_cat $1 -fill 0xff 0x000000 $3 -o $2 -raw;
if [ "$?" -ne 0 ];
then
  echo "An error occurred.";
  exit 1;
fi

echo "Binary data has been successfully written to: "$2
exit 0
